@@ -83,10 +83,12 @@ class CapacityPredictionModel:
             os.makedirs(directory, exist_ok=True)
 
         # save model
-        pickle.dump(self.model, open(directory / "model.pkl", "wb"))
+        with open(directory / "model.pkl", "wb") as fh:
+            pickle.dump(self.model, fh)
 
         # save classes
-        pickle.dump(self.classes, open(directory / "classes.pkl", "wb"))
+        with open(directory / "classes.pkl", "wb") as fh:
+            pickle.dump(self.classes, fh)
 
     def load(self, directory):
         # load model
