@@ -8,7 +8,7 @@ from ktpbase.config.config import ConfigManager
 from ktpbase.log import logging
 
 
-def post_teams(msg, url=None):
+def post_teams(msg, invalid_coefs=None, coefsdf=None, url=None):
     """Post a message to Teams - KTP
 
     Note that currently no authentication occurs.
@@ -22,6 +22,9 @@ def post_teams(msg, url=None):
             text, links, sections. Each section can contain the following keys:
             text, title, images, facts, markdown. Also see:
             https://docs.microsoft.com/en-us/outlook/actionable-messages/send-via-connectors
+        invalid_coefs (pd.DatFrame, optional): df of information of invalid
+            coefficients. Defaults to None.
+        coefsdf (pd.DataFrame, optional): df of new coefficients. Defaults to None.
         url (string, optional): webhook url, monitoring by default
 
     Note:
@@ -83,7 +86,7 @@ def post_teams(msg, url=None):
     card.send()
 
 
-def post_teams_alert(msg, invalid_coefs=None, coefsdf=None, url=None):
+def post_teams_alert(msg, url=None):
     """Same as post_teams, but posts to alert channel.
 
     Args:
@@ -92,49 +95,11 @@ def post_teams_alert(msg, invalid_coefs=None, coefsdf=None, url=None):
             text, links, sections. Each section is a dict and can contain the
             following keys: text, title, images, facts, markdown. Also see:
             https://docs.microsoft.com/en-us/outlook/actionable-messages/send-via-connectors
-        invalid_coefs (pd.DatFrame, optional): df of information of invalid
-            coefficients. Defaults to None.
-        coefsdf (pd.DataFrame, optional): df of new coefficients. Defaults to None.
+
     Note:
         This function is namespace-specific.
     """
     config = ConfigManager.get_instance()
-    # Add invalid coefficients and manual coefficients-query to message
-    if invalid_coefs is not None and coefsdf is not None:
-        # add invalid coefficient information to message in dict-format
-        invalid_coefs_text = "".join(
-            [
-                f"\n* **{row.coef_name}**: {round(row.coef_value_new, 2)}, "
-                f"(previous: {round(row.coef_value_last, 2)})"
-                for index, row in invalid_coefs.iterrows()
-            ]
-        )
-        query = build_sql_query_string(coefsdf, "energy_split_coefs")
-        query_text = "If you would like to update the coefficients manually in the "
-        f"database, use this query:"
-        msg = {
-            "fallback": msg,
-            "title": "Invalid energy splitting coefficients",
-            "sections": [
-                {
-                    "text": msg,
-                    "markdown": True,
-                },
-                {
-                    "text": invalid_coefs_text,
-                    "markdown": True,
-                },
-                {
-                    "title": "Manual query",
-                    "text": query_text,
-                    "markdown": True,
-                },
-                {
-                    "text": query,
-                    "markdown": True,
-                },
-            ],
-        }
     if url is None:
         if hasattr(config, "teams") is True:
             url = config.teams.alert_url
@@ -162,13 +127,17 @@ def build_sql_query_string(df, table):
         df[col] = df[col].astype("str")
 
     sql_texts = [
-        "```INSERT INTO " + table + " (" + str(", ".join(df.columns)) + ") VALUES  \n"
+        "```  \nINSERT INTO "
+        + table
+        + " ("
+        + str(", ".join(df.columns))
+        + ") VALUES  \n"
     ]
     for index, row in df.iterrows():
         if index != df.index[0]:
             sql_texts.append(",  \n")  # 2 spaces and \n create a new line
         sql_texts.append(str(tuple(row.values)))
-    sql_texts.append("```")
+    sql_texts.append("  \n```")
     query = "".join(sql_texts)
     return query
 
